@@ -37,10 +37,10 @@ class ActivityDetail(AbstractModel):
         :param ActivityType: 活动类型，100:留资活动
 注意：此字段可能返回 null，表示取不到有效值。
         :type ActivityType: int
-        :param StartTime: 活动开始时间，单位：秒
+        :param StartTime: 活动开始时间戳，单位：秒
 注意：此字段可能返回 null，表示取不到有效值。
         :type StartTime: int
-        :param EndTime: 活动结束时间，单位：秒
+        :param EndTime: 活动结束时间戳，单位：秒
 注意：此字段可能返回 null，表示取不到有效值。
         :type EndTime: int
         :param MainPhoto: 活动主图
@@ -49,7 +49,7 @@ class ActivityDetail(AbstractModel):
         :param PrivacyAgreementId: 协议编号
 注意：此字段可能返回 null，表示取不到有效值。
         :type PrivacyAgreementId: str
-        :param UpdateTime: 活动更新时间，单位：秒
+        :param UpdateTime: 活动更新时间戳，单位：秒
 注意：此字段可能返回 null，表示取不到有效值。
         :type UpdateTime: int
         :param ActivityDataList: 活动数据列表
@@ -288,7 +288,7 @@ class ChatArchivingDetail(AbstractModel):
         :type MsgId: str
         :param Action: 动作名称，switch表示切换企微账号，send表示企微普通消息
         :type Action: str
-        :param MsgType: 消息类型，当Action != "switch"时存在，比如video, text, voice 等，和企微开放文档一一对应
+        :param MsgType: 消息类型，当Action != "switch"时存在，例如video, text, voice 等，和企微开放文档一一对应
 https://open.work.weixin.qq.com/api/doc/90000/90135/91774
 注意：此字段可能返回 null，表示取不到有效值。
         :type MsgType: str
@@ -559,12 +559,16 @@ class ExternalContact(AbstractModel):
         :param UnionId: 外部联系人在微信开放平台的唯一身份标识（微信unionid），通过此字段企业可将外部联系人与公众号/小程序用户关联起来。仅当联系人类型是微信用户，且企业或第三方服务商绑定了微信开发者ID有此字段。
 注意：此字段可能返回 null，表示取不到有效值。
         :type UnionId: str
+        :param Phone: 外部联系人联系电话
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Phone: str
         """
         self.ExternalUserId = None
         self.Gender = None
         self.Name = None
         self.Type = None
         self.UnionId = None
+        self.Phone = None
 
 
     def _deserialize(self, params):
@@ -573,6 +577,7 @@ class ExternalContact(AbstractModel):
         self.Name = params.get("Name")
         self.Type = params.get("Type")
         self.UnionId = params.get("UnionId")
+        self.Phone = params.get("Phone")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -593,14 +598,19 @@ class ExternalContactSimpleInfo(AbstractModel):
         :type ExternalUserId: str
         :param UserId: 添加了此外部联系人的企业成员userId
         :type UserId: str
+        :param SalesName: 添加了此外部联系人的企业成员的姓名
+注意：此字段可能返回 null，表示取不到有效值。
+        :type SalesName: str
         """
         self.ExternalUserId = None
         self.UserId = None
+        self.SalesName = None
 
 
     def _deserialize(self, params):
         self.ExternalUserId = params.get("ExternalUserId")
         self.UserId = params.get("UserId")
+        self.SalesName = params.get("SalesName")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -665,9 +675,9 @@ class FollowUser(AbstractModel):
         :param Description: 该成员对此外部联系人的描述
 注意：此字段可能返回 null，表示取不到有效值。
         :type Description: str
-        :param CreateTime: 该成员添加此外部联系人的时间,单位为秒
+        :param CreateTime: 该成员添加此外部联系人的时间戳，单位为秒
         :type CreateTime: int
-        :param AddWay: 该成员添加此客户的来源，具体含义详见来<a href="https://work.weixin.qq.com/api/doc/90000/90135/92114#%E6%9D%A5%E6%BA%90%E5%AE%9A%E4%B9%89">来源定义</a>
+        :param AddWay: 该成员添加此客户的来源，具体含义详见<a href="https://work.weixin.qq.com/api/doc/90000/90135/92114#%E6%9D%A5%E6%BA%90%E5%AE%9A%E4%B9%89">来源定义</a>
         :type AddWay: int
         :param OperUserId: 发起添加的userid，如果成员主动添加，为成员的userid；如果是客户主动添加，则为客户的外部联系人userid；如果是内部成员共享/管理员分配，则为对应的成员/管理员userid
         :type OperUserId: str
